==> daikon-1.0.tar.gz: daikon-1.0/src/XMLParser/WindowElement.cpp <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#include <iostream>
#include <stdlib.h>
#include <string.h>

#include "../Window.h"
#include "WindowElement.h"

using namespace std;

WindowElement::WindowElement(char* superID)
{
    this->name = "ウィンドウ";
    this->superID = superID;

    width = NULL;
    height = NULL;
    bpp = NULL;
    fullscreen = NULL;
    window = NULL;
}

Element* WindowElement::getChild(char* name, char* super)
{
    if ( strcmp("幅", name) == 0 ) {
        width = new Element(name, super);
        return width;
    }
    else if ( strcmp("高さ", name) == 0 ) {
        height = new Element(name, super);
        return height;
    }
    else if ( strcmp("色数", name) == 0 ) {
        bpp = new Element(name, super);
        return bpp;
    }
    else if ( strcmp("フルスクリーン", name) == 0 ) {
        fullscreen = new Element(name, super);
        return fullscreen;
    }
    else {
        invalidElement(name);
    }
}

void WindowElement::endElement()
{
}

int WindowElement::getWidth(list<string>* path)
{
    checkInheritance(getWidth, width, WindowElement, 320);
    return atoi(width->getValue(NULL).c_str());
}

int WindowElement::getHeight(list<string>* path)
{
    checkInheritance(getHeight, height, WindowElement, 200);
    return atoi(height->getValue(NULL).c_str());
}

int WindowElement::getBPP(list<string>* path)
{
    checkInheritance(getBPP, bpp, WindowElement, 32);
    return atoi(bpp->getValue(NULL).c_str());
}

bool WindowElement::getFullscreen(list<string>* path)
{
    checkInheritance(getFullscreen, fullscreen, WindowElement, false);
    if ( fullscreen->getValue(NULL) == "ON" ) {
        return true;
    }
    else {
        return false;
    }
}

Window* WindowElement::getWindow(list<string>* path) {
    if ( window != NULL ) { return window; }
    window = new Window();
    window->setWidth(getWidth(NULL));
    window->setHeight(getHeight(NULL));
    // window->setBPP(getBPP(NULL));
    // window->setFullscreen(getFullscreen(NULL));
    return window;
}

==> daikon-1.0.2.tar.gz: daikon-1.0.2/src/XMLParser/WindowElement.cpp <==
/*

ダイコン： STGスクリプトインタープリタは日本語XMLタグによるシューティングゲームのエンジンです。
Copyright (C) 2009 karasimiso

このプログラムはフリーソフトウェアです。あなたはこれを、フリーソフトウェア財団によって発行されたGNU 一般公衆利用許諾書(バージョン3か、 それ以降のバージョンのうちどれか)が定める条件の下で再頒布または改変することができます。

このプログラムは有用であることを願って頒布されますが、*全くの無保証 *です。商業可能性の保証や特定目的への適合性は、言外に示されたものも 含め、全く存在しません。詳しくはGNU 一般公衆利用許諾書をご覧ください。

あなたはこのプログラムと共に、GNU 一般公衆利用許諾書のコピーを一部受け取っているはずです。もし受け取っていなければ、<http://www.gnu.org/licenses/> をご覧ください。



Daikon: STG Script Interpreter is game engine for shooting game in Japanese XML tags.
Copyright (C) 2009 karasimiso

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

#include <iostream>
#include <stdlib.h>
#include <string.h>

#include "../Window.h"
#include "WindowElement.h"

using namespace std;

WindowElement::WindowElement(char* superID)
{
    this->name = "ウィンドウ";
    this->superID = superID;

    width = NULL;
    height = NULL;
    bpp = NULL;
    fullscreen = NULL;
    window = NULL;
}

Element* WindowElement::getChild(char* name, char* super)
{
    if ( strcmp("幅", name) == 0 ) {
        width = new Element(name, super);
        return width;
    }
    else if ( strcmp("高さ", name) == 0 ) {
        height = new Element(name, super);
        return height;
    }
    else if ( strcmp("色数", name) == 0 ) {
        bpp = new Element(name, super);
        return bpp;
    }
    else if ( strcmp("フルスクリーン", name) == 0 ) {
        fullscreen = new Element(name, super);
        return fullscreen;
    }
    else {
        invalidElement(name);
    }
}

void WindowElement::endElement()
{
}

int WindowElement::getWidth(list<string>* path)
{
    checkInheritance(getWidth, width, WindowElement, 320);
    return atoi(width->getValue(NULL).c_str());
}

int WindowElement::getHeight(list<string>* path)
{
    checkInheritance(getHeight, height, WindowElement, 200);
    return atoi(height->getValue(NULL).c_str());
}

int WindowElement::getBPP(list<string>* path)
{
    checkInheritance(getBPP, bpp, WindowElement, 32);
    return atoi(bpp->getValue(NULL).c_str());
}

bool WindowElement::getFullscreen(list<string>* path)
{
    checkInheritance(getFullscreen, fullscreen, WindowElement, false);
    if ( fullscreen->getValue(NULL) == "ON" ) {
        return true;
    }
    else {
        return false;
    }
}

Window* WindowElement::getWindow(list<string>* path)
{
    if ( window != NULL ) { return window; }
    window = new Window();
    window->setWidth(getWidth(NULL));
    window->setHeight(getHeight(NULL));
    // window->setBPP(getBPP(NULL));
    // window->setFullscreen(getFullscreen(NULL));
    return window;
}

WindowElement::~WindowElement()
{
    delete bpp;
    delete width;
    delete height;
    delete fullscreen;
}
